lilypondparsertools.LilyPondParser
==================================

.. inheritance-diagram:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser
   :private-bases:

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.available_languages

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.debug

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.lexer

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.lexer_rules_object

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.logger

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.logger_path

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.output_path

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.parser

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.parser_rules_object

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.pickle_path

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.default_language

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.register_markup_function

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.tokenize

    Inherited from :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser.Parser>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__call__

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.LilyPondParser.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
